//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define IDS_FAIL_CREATEFILE             1
#define IDS_FAIL_MAPVIEWOFFILE          3
#define IDS_SCRIPT_NOT_FOUND            4
#define IDS_FAIL_MODIFY_IMPORT_TABLE    5
#define IDS_FAIL_GETPROCADDRESS         6
#define IDS_CANNOT_EXECUTE_SCRIPT       7
#define IDS_CANNOT_OBTAIN_EXCEPTION     8
#define IDS_HEADER_NOT_FOUND            9
#define IDD_EXCEPTION                   101
#define IDI_RUBY                        102
#define IDI_EXCEPTION                   103
#define ID_CLOSE                        1000
#define ID_DETAIL                       1001
#define IDC_EDIT_MESSAGE                1002
#define IDC_EDIT_CALLSTACK              1003
#define IDC_EDIT_BACKTRACE              1003
#define IDC_EDIT_TYPE                   1004

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        103
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1005
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
